# Super Sitemap

There are plenty of great sitemap options for use with Drupal. However this can often fail to scale well for large or enterprise Drupal installations. Additionally, they are usually tightly-coupled with the Drupal entity system with the ability to add custom links after the fact. This module addresses those limitations by enabling sitemap generation from XML data sources and supporting custom base paths - making it easier to manage multiple Drupal instances under a single domain.


For a full description of the module, visit the
[project page](https://www.drupal.org/project/super_sitemap).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/super_sitemap).


## Table of contents

- Requirements
- Installation
- Features


## Requirements

**Required modules:**
- [Simple XML sitemap](https://www.drupal.org/project/simple_sitemap)
- [Ultimate Cron](https://www.drupal.org/project/ultimate_cron)


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Features

### Sitemap link generation from external XML sitemap markup
The Super Sitemap module supports sitemap generation from an external source via raw XML sitemap markup. This is particularly useful for inclusion of pages from non-Drupal applications hosted under the same domain - for instance, single-page applications (SPAs). 

#### 1. Add a new sitemap that will contain only links from external data sources
1. Go to /admin/config/search/simplesitemap
2. Click "Add sitemap".
3. Provide a "Label" - e.g., "Super Sitemap External XML".
5. Under "Sitemap type", choose "Super Sitemap External XML".
Save.

#### 2. Add a new data source
1. Go to /admin/config/search/simplesitemap/super-extras/data-sources
2. Click "Add data source" to create a new data source.
3. Enter a label to identify the data source.
4. Under "Sitemap", choose the sitemap you created - e.g., "Super Sitemap External XML".
5. Fill in the "XML source". This should be valid sitemap XML markup.
6. Save.

#### 3. Generate the sitemap
1. Go to /admin/config/search/simplesitemap
2. Click "Rebuild queue & generate".
3. After the sitemaps have been regenerated, view the external sitemap you created. 
4. Confirm that the sitemap contains the links from the created data sources that have the "Sitemap" field set to the sitemap being viewed.

### Adding custom links to a sitemap
In addition to including Drupal content and external data sources, the Super Sitemap module allows you to add custom links to your sitemap. These custom links can be used to include URLs that are not part of your Drupal site's content or external XML sources. Custom links are managed through the Simple XML Sitemap interface and will be included alongside other content in the generated sitemap.

To add custom links:
1. Go to /admin/config/search/simplesitemap/super-extras/custom-urls.
2. Click "Add custom url".
3. Enter the URL and any additional metadata (URL type, priority, change frequency).
4. Save the custom link.
5. Rebuild the sitemap to include the new custom links.

### Configuring a custom base path for sitemap URLs

By default, Simple Sitemap assumes that sitemaps are generated at the root of the Drupal installation (e.g., /sitemap.xml). However, if your site is installed at a subpath or you want your sitemap to be served from a custom location (e.g., /my-site/sitemap.xml), you can configure a custom base path for the sitemap's URL.

This is managed as a third-party setting in the Super Sitemap configuration. When set, the Super Sitemap module will alter the existing sitemap route to serve the sitemap from the new base path you specify, rather than the default location.

**Use case**

If your Drupal site is not installed at the web root, or you want to organize sitemaps under a specific subpath (e.g., /my-site/sitemap.xml), you can set a custom base path so that search engines and other consumers can find your sitemap at the correct location.

**How to configure:**
1. Go to the Super Sitemap settings page (e.g., /admin/config/search/simplesitemap/settings).
2. Set the "Default base path" to your desired subpath (e.g., /my-site).
3. Save the configuration.
4. The sitemap will now be available at the new base path you specified.